@@ -6,17 +6,12 @@ describe 'aodh' do
 
     it { is_expected.to contain_class('aodh::deps') }
     it { is_expected.to contain_class('aodh::db') }
-    it { is_expected.to contain_class('aodh::logging') }
 
     context 'with default parameters' do
       let :params do
         { :purge_config => false  }
       end
 
-      it 'contains the logging class' do
-        is_expected.to contain_class('aodh::logging')
-      end
-
       it 'installs packages' do
         is_expected.to contain_package('aodh').with(
           :name   => platform_params[:aodh_common_package],
@@ -26,11 +21,13 @@ describe 'aodh' do
       end
 
       it 'configures rabbit' do
+        is_expected.to contain_aodh_config('DEFAULT/executor_thread_pool_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
@@ -48,11 +45,12 @@ describe 'aodh' do
     context 'with overridden parameters' do
       let :params do
         {
-          :debug                              => true,
+          :executor_thread_pool_size          => '128',
           :default_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
           :rabbit_ha_queues                   => 'undef',
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
+          :rabbit_heartbeat_in_pthread        => true,
           :kombu_compression                  => 'gzip',
           :package_ensure                     => '2012.1.1-15.el6',
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
@@ -63,9 +61,11 @@ describe 'aodh' do
       end
 
       it 'configures rabbit' do
+        is_expected.to contain_aodh_config('DEFAULT/executor_thread_pool_size').with_value('128')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
+        is_expected.to contain_aodh_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true)
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip')
         is_expected.to contain_aodh_config('database/alarm_history_time_to_live').with_value('604800')
       end
